@@ -27,26 +27,36 @@ class LkeapClient(AbstractClient):
 
 
     def ChatCompletions(self, request):
-        """#### 接口功能
+        """### 接口功能
 
-        调用接口，发起一次对话请求。
+        调用接口，发起一次对话请求。单账号限制接口并发上限为100。
         如需使用OpenAI兼容接口， 请参考文档：[Deepseek OpenAI对话接口](https://cloud.tencent.com/document/product/1772/115969)
 
+        #### 在线体验
+        如您希望在网页内直接体验 DeepSeek 模型对话，推荐您前往[腾讯云大模型知识引擎](https://cloud.tencent.com/product/lke)，使用[ DeepSeek 联网助手](https://lke.cloud.tencent.com/webim_exp/#/chat/wQrAwR)。
+
         #### 已支持的模型
+        - DeepSeek-V3-0324（model 参数值为**deepseek-v3-0324**）
+            - DeepSeek-V3-0324为671B参数MoE模型，在编程与技术能力、上下文理解与长文本处理等方面优势突出。
+            - 支持128K上下文长度，最大输出16k（不含思维链）。
+            - 注意：相比于DeepSeek-V3，DeepSeek-V3-0324仅更新了模型权重，未增加参数量。总模型大小为685B，其中包括671B的主模型权重和 14B 的多令牌预测（MTP）模块权重，后续均描述主模型参数量。
         - DeepSeek-V3（model 参数值为**deepseek-v3**）
             - DeepSeek-V3为671B参数MoE模型，在百科知识、数学推理等多项任务上优势突出，评测成绩在主流榜单中位列开源模型榜首。
-            - 支持64K上下文长度，最大输入56k，最大输出8k（不含思维链）。
+            - 支持64K上下文长度，最大输出16k。
         - DeepSeek-R1（model 参数值为**deepseek-r1**）
             - DeepSeek-R1为671B模型，使用强化学习训练，推理过程包含大量反思和验证，思维链长度可达数万字。 该系列模型在数学、代码以及各种复杂逻辑推理任务上推理效果优异，并为用户展现了完整的思考过程。
-            -  支持64K上下文长度，最大输入56k，最大输出8k（不含思维链）。
+            -  支持64K上下文长度，最大输出16k。
 
-        #### 计费说明
-        - 限时免费
+        ### 计费说明
 
-        本接口调用DeepSeek系列模型限时免费。即日至北京时间2025年2月25日23:59:59，所有腾讯云用户均可享受DeepSeek-V3、DeepSeek-R1模型限时免费服务，单账号限制接口并发上限为5。在此之后，模型价格将恢复至原价。
-        - 标准计费（2025年2月26日起生效）
+        - 标准计费（2025年2月26日起生效），计费模式为后付费小时结，为保证您账户资源的正常使用，请提前[开通后付费](https://lke.cloud.tencent.com/lke#/app/system/charge/postpaid)并及时[充值](https://console.cloud.tencent.com/expense/recharge)。
+
+            -   DeepSeek-R1 模型   | 输入：0.004元/千token | 输出（含思维链）：0.016元/千token
+
+            - DeepSeek-V3 模型 | 输入：0.002元/千token | 输出：0.008元/千token
+
+            - DeepSeek-V3-0324 模型 | 输入：0.002元/千token | 输出：0.008元/千token
 
-         ![image](https://cdn.xiaowei.qq.com/static/lke/deekseep-token0212.png)
 
         ### Openai兼容协议接口
         知识引擎原子能力大模型对话 API 兼容了 OpenAI 的接口规范，这意味着您可以直接使用 OpenAI 官方提供的 SDK 来调用大模型对话接口。您仅需要将 base_url 和 [api_key](https://cloud.tencent.com/document/product/1772/115970) 替换成相关配置，不需要对应用做额外修改，即可无缝将您的应用切换到相应的大模型。请参考文档：[Deepseek OpenAI对话接口](https://cloud.tencent.com/document/product/1772/115969)。
@@ -55,7 +65,7 @@ class LkeapClient(AbstractClient):
         > api_key的获取请参考[API KEY管理](https://cloud.tencent.com/document/product/1772/115970)
 
 
-        #### 快速接入
+        ### 快速接入
         1. 完成[实名认证](https://console.cloud.tencent.com/developer/auth)。
         2. 主账户前往[控制台](https://console.cloud.tencent.com/lkeap)开通服务。若为子账户，需由主账号在[权限管理](https://console.cloud.tencent.com/cam)中为子账号授权，关联预设策略，策略名称：QcloudLKEAPFullAccess。
         3. 通过API Explorer[在线调试](https://console.cloud.tencent.com/api/explorer?Product=lkeap&Version=2024-05-22&Action=ChatCompletions)。
@@ -163,7 +173,7 @@ class LkeapClient(AbstractClient):
 
 
     def CreateKnowledgeBase(self, request):
-        """用于在系统中创建一个新的知识库。知识库是一个用于存储和管理知识条目的集合，可以包括文档、问答对、属性标签等。创建知识库后，可以向其中添加各种知识条目，以便在后续的知识检索中使用。 使用场景：当需要在系统中建立一个新的知识库以存储和管理特定领域或项目的知识条目时使用。例如，一个用户可能需要创建一个知识库，以存储用户指南、常见问题解答和技术文档。
+        """用于在系统中创建一个新的知识库。知识库是一个用于存储和管理知识条目的集合，可以包括文档、问答对、属性标签等。创建知识库后，可以向其中添加各种知识条目，以便在后续的知识检索中使用。 使用场景：当需要在系统中建立一个新的知识库以存储和管理特定领域或项目的知识条目时使用。例如，一个用户可能需要创建一个知识库，以存储用户指南、常见问题解答和技术文档。体验用户最多可创建3个知识库，付费用户最多可创建100个知识库。
 
         :param request: Request instance for CreateKnowledgeBase.
         :type request: :class:`tencentcloud.lkeap.v20240522.models.CreateKnowledgeBaseRequest`
@@ -210,7 +220,7 @@ class LkeapClient(AbstractClient):
 
     def CreateReconstructDocumentFlow(self, request):
         """本接口为异步接口的发起请求接口，用于发起文档解析任务。
-        文档解析支持将图片或PDF文件转换成Markdown格式文件，可解析包括表格、公式、图片、标题、段落、页眉、页脚等内容元素，并将内容智能转换成阅读顺序。
+        文档解析支持将图片或PDF、DOCX、PPTX、EXCEL等文件转换成Markdown格式文件，可解析包括表格、公式、图片、标题、段落、页眉、页脚等内容元素，并将内容智能转换成阅读顺序。具体支持文件类型请查看下方输入参数列表。
 
         体验期间单账号限制qps仅为1，若有正式接入需要请与产研团队沟通开放。
 
@@ -372,6 +382,29 @@ class LkeapClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def GetCharacterUsage(self, request):
+        """获取字符使用量统计
+
+        :param request: Request instance for GetCharacterUsage.
+        :type request: :class:`tencentcloud.lkeap.v20240522.models.GetCharacterUsageRequest`
+        :rtype: :class:`tencentcloud.lkeap.v20240522.models.GetCharacterUsageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetCharacterUsage", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetCharacterUsageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def GetEmbedding(self, request):
         """本接口（GetEmbedding）调用文本表示模型，将文本转化为用数值表示的向量形式，可用于文本检索、信息推荐、知识挖掘等场景。
         本接口（GetEmbedding）有单账号调用上限控制，如您有提高并发限制的需求请 [联系我们](https://cloud.tencent.com/act/event/Online_service) 。
